{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Running cellranger count and lineage inference",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/chemistry"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#main/fastq_directory"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 3,
                    "id": "#main/lineage_min_cells"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 10,
                    "id": "#main/lineage_min_features"
                },
                {
                    "type": "string",
                    "id": "#main/lineage_reference_data"
                },
                {
                    "type": "Directory",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                }
            ],
            "steps": [
                {
                    "run": "#cellranger_count.cwl",
                    "in": [
                        {
                            "source": "#main/chemistry",
                            "id": "#main/count/chemistry"
                        },
                        {
                            "source": "#main/fastq_directory",
                            "id": "#main/count/fastq_directory"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/count/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/count/sample_name"
                        }
                    ],
                    "out": [
                        "#main/count/out_dir"
                    ],
                    "id": "#main/count"
                },
                {
                    "run": "#cellmatch_lineage.cwl",
                    "in": [
                        {
                            "source": "#main/count/out_dir",
                            "id": "#main/lineage/cellranger_out_dir"
                        },
                        {
                            "source": "#main/lineage_min_cells",
                            "id": "#main/lineage/lineage_min_cells"
                        },
                        {
                            "source": "#main/lineage_min_features",
                            "id": "#main/lineage/lineage_min_features"
                        },
                        {
                            "source": "#main/lineage_reference_data",
                            "id": "#main/lineage/lineage_reference_data"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/lineage/sample_name"
                        }
                    ],
                    "out": [
                        "#main/lineage/cellmatch_out_dir"
                    ],
                    "id": "#main/lineage"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/count/out_dir",
                    "id": "#main/counts_out_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/lineage/cellmatch_out_dir",
                    "id": "#main/lineage_cellmatch_lineage_out_dir"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Running a script to identify lineage of cells",
            "baseCommand": [
                "/usr/local/bin/Rscript",
                "/opt/CellMatch_Haemopedia.r"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/scrna_lineage_inference:0.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 1
                }
            ],
            "arguments": [
                "$(inputs.cellranger_out_dir)/filtered_feature_bc_matrix",
                "cellmatch"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#cellmatch_lineage.cwl/cellranger_out_dir"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 3,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cellmatch_lineage.cwl/lineage_min_cells"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 10,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#cellmatch_lineage.cwl/lineage_min_features"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cellmatch_lineage.cwl/lineage_reference_data"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#cellmatch_lineage.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "cellmatch"
                    },
                    "id": "#cellmatch_lineage.cwl/cellmatch_out_dir"
                }
            ],
            "id": "#cellmatch_lineage.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Run Cell Ranger Count",
            "baseCommand": [
                "/apps/cellranger-6.0.0/cellranger",
                "count"
            ],
            "arguments": [
                "--id=$(inputs.sample_name)",
                "--localcores=$(runtime.cores)",
                "--localmem=$(runtime.ram/1000)"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/alex.paul/cellranger:6.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 56000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--chemistry=",
                        "position": 1,
                        "separate": false
                    },
                    "default": "auto",
                    "doc": "Assay configuration used, default 'auto' should usually work without issue",
                    "id": "#cellranger_count.cwl/chemistry"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "prefix": "--fastqs=",
                        "position": 2,
                        "itemSeparator": ",",
                        "separate": false
                    },
                    "doc": "Array of directories containing fastq files",
                    "id": "#cellranger_count.cwl/fastq_directory"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--transcriptome=",
                        "position": 3,
                        "separate": false
                    },
                    "doc": "Transcriptome reference compatible with input species and Cell Ranger",
                    "id": "#cellranger_count.cwl/reference"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sample=",
                        "position": 4,
                        "separate": false
                    },
                    "doc": "Sample name, must be same as name specified in sample sheet in previous mkfastq step",
                    "id": "#cellranger_count.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name)/outs/"
                    },
                    "id": "#cellranger_count.cwl/out_dir"
                }
            ],
            "id": "#cellranger_count.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
